@@ -4,33 +4,39 @@ from .kernels import (
     adaptive_tempered_smc,
     elliptical_slice,
     hmc,
+    irmh,
     mala,
+    mgrad_gaussian,
     nuts,
     orbital_hmc,
     pathfinder_adaptation,
     rmh,
+    sghmc,
     sgld,
     tempered_smc,
     window_adaptation,
 )
 from .optimizers import dual_averaging, lbfgs
 
-__version__ = "0.8.2"
+__version__ = "0.8.3"
 
 __all__ = [
-    "dual_averaging",
+    "dual_averaging",  # optimizers
     "lbfgs",
     "hmc",  # mcmc
     "mala",
+    "mgrad_gaussian",
     "nuts",
     "orbital_hmc",
     "rmh",
+    "irmh",
     "elliptical_slice",
     "sgld",  # stochastic gradient mcmc
+    "sghmc",
     "window_adaptation",  # mcmc adaptation
+    "pathfinder_adaptation",
     "adaptive_tempered_smc",  # smc
     "tempered_smc",
     "ess",  # diagnostics
     "rhat",
-    "pathfinder_adaptation",
 ]
